<?php
/*
Plugin Name: Libro de Reclamaciones
Plugin URI: http://www.paginasweb.pe
Description: Crea un formulario y almacena reclamos en la base de datos en orden correlativo.
Version: 1.0.1
Author: PaginasWeb.pe
Author URI: http://www.paginasweb.pe
License: GPL2

  	Copyright 2014 PaginasWeb.pe  (email : hola@paginasweb.pe)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as 
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/

/********** Database **********/

global $pwreclamaciones_db_version;
$pwreclamaciones_db_version = '1.0';

function pwreclamaciones_db_create() {
	global $wpdb;
	global $pwreclamaciones_db_version;
	
	$table_name = $wpdb->prefix . 'pwreclamaciones';
	
	$sql = "CREATE TABLE $table_name (
		reclamo_id int(11) NOT NULL AUTO_INCREMENT,
		usuario_nombre VARCHAR(255) DEFAULT '' NOT NULL,
		usuario_ap_paterno VARCHAR(255) DEFAULT '' NOT NULL,
		usuario_ap_materno VARCHAR(255) DEFAULT '' NOT NULL,
		usuario_documento VARCHAR(255) DEFAULT '' NOT NULL,
		usuario_direccion TEXT NOT NULL,
		usuario_departamento VARCHAR(255) DEFAULT '' NOT NULL,
		usuario_provincia VARCHAR(255) DEFAULT '' NOT NULL,
		usuario_distrito VARCHAR(255) DEFAULT '' NOT NULL,
		usuario_email VARCHAR(255) DEFAULT '' NOT NULL,
		usuario_telefono VARCHAR(255) DEFAULT '' NOT NULL,
		usuario_fecha VARCHAR(10) DEFAULT '00/00/00' NOT NULL,
		usuario_comentario TEXT,
		fecha_envio DATE NOT NULL,
		UNIQUE KEY reclamo_id (reclamo_id)
	);";
	
	require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
	dbDelta( $sql );
	
	add_option( 'pwreclamaciones_db_version', $pwreclamaciones_db_version );
}

function pwreclamaciones_db_install() {
	global $wpdb;
	
	date_default_timezone_set('America/Bogota');
	$current_date = date('d/m/Y', time());
	
	$usuario_nombre = 'Mr. WordPress';
	$usuario_ap_paterno = '---';
	$usuario_ap_materno = '---';
	$usuario_documento = '0000000';
	$usuario_direccion = __('- No disponible -');
	$usuario_departamento = '---';
	$usuario_provincia = '---';
	$usuario_distrito = '---';
	$usuario_email = 'mail@mail.com';
	$usuario_telefono = '0000000';
	$usuario_comentario = __('Este es un reclamo de prueba');
	
	$table_name = $wpdb->prefix . 'pwreclamaciones';
	
	$rows_affected = $wpdb->insert( $table_name, 
		array( 
			'usuario_nombre' 		=> $usuario_nombre,
			'usuario_ap_paterno' 	=> $usuario_ap_paterno,
			'usuario_ap_materno' 	=> $usuario_ap_materno,
			'usuario_documento'		=> $usuario_documento,
			'usuario_direccion'		=> $usuario_direccion,
			'usuario_departamento'	=> $usuario_departamento,
			'usuario_provincia'		=> $$usuario_provincia,
			'usuario_distrito'		=> $usuario_distrito,
			'usuario_email'			=> $usuario_email,
			'usuario_telefono'		=> $usuario_telefono,
			'usuario_fecha'			=> $current_date,
			'usuario_comentario'	=> $usuario_comentario,
			'fecha_envio'			=> date('Y-m-d H:i:s', time())
		));
}

register_activation_hook( __FILE__, 'pwreclamaciones_db_create' );
register_activation_hook( __FILE__, 'pwreclamaciones_db_install' );

/********** Form Shortcode Class **********/

class pwreclamaciones_shortcode {
	static $add_script;

	static function init() {
		add_shortcode('formulario-reclamaciones', array(__CLASS__, 'handle_reclamos_shortcode'));

		add_action('init', array(__CLASS__, 'register_script'));
		add_action('wp_footer', array(__CLASS__, 'print_script'));
	}

	static function handle_reclamos_shortcode($atts, $content = null) {
		self::$add_script = true;
		?>
		 <div id="contact-form">
				<?php if ( isset( $_POST['ct_submit'] ) ) : ?>
					<?php
					// Form data
					$nombre = $_POST['ct_nombre'];
					$apellido_paterno = $_POST['ct_apellido_paterno'];
					$apellido_materno = $_POST['ct_apellido_materno'];
					$tipo_doc = $_POST['ct_tipo_doc'];
					$nro_doc = $_POST['ct_nro_doc'];
					$direccion = $_POST['ct_direccion'];
					$departamento = $_POST['ct_departamento'];
					$provincia = $_POST['ct_provincia'];
					$distrito = $_POST['ct_distrito'];
					$email = $_POST['ct_email'];
					$telefono = $_POST['ct_telefono'];
					
					$fecha_incidencia = $_POST['ct_fecha_incidencia'];
					$comment = $_POST['ct_comentario'];
	
					// Mail details
					$to = get_option( 'admin_email' );
					$subject = __( 'Reclamo enviado desde ' ) . get_option( 'blogname' );
	
					$message = __('Usuario:') . ' ' . $nombre . ' ' . $apellido_paterno . ' ' . $apellido_materno . "\n";
					$message .= __('Email:') . ' ' . $email . "\n";
					$message .= __('Fecha de incidencia:') . ' ' . $fecha_incidencia . "\n";
					$message .= __('Comentario:') . " \n\n";
					$message .= $comment;
					
					$headers = 'From: ' . $nombre . ' <' . $email . '>' . "\r\n";
					
					// Email para el administrador
					wp_mail( $to, $subject, $message, $headers );
					
					// Email para el usuario
					$message_user = "Estimado $nombre $apellido_paterno,\r\n\r\nMuchas gracias por dejarnos su opinión sobre nuestros servicios. Su reclamo ha sido recepcionado correctamente.";
					$headers = 'From: ' . get_option( 'blogname' ) . ' <no-responder@mail.com>' . "\r\n";
					
					wp_mail( $email, __('Hemos recibido su reclamo'), $message_user, $headers );
					
					// Save in database
					global $wpdb;
					$table_name = $wpdb->prefix . 'pwreclamaciones';
					
					$wpdb->insert($table_name, array(
						'usuario_nombre' 		=> mysql_real_escape_string($nombre),
						'usuario_ap_paterno' 	=> mysql_real_escape_string($apellido_paterno),
						'usuario_ap_materno'	=> mysql_real_escape_string($apellido_materno),
						'usuario_documento'		=> mysql_real_escape_string($tipo_doc . ' ' . $nro_doc),
						'usuario_direccion'		=> mysql_real_escape_string($direccion),
						'usuario_departamento'	=> mysql_real_escape_string($departamento),
						'usuario_provincia'		=> mysql_real_escape_string($provincia),
						'usuario_distrito'		=> mysql_real_escape_string($distrito),
						'usuario_email'			=> mysql_real_escape_string($email),
						'usuario_telefono'		=> mysql_real_escape_string($telefono),
						'usuario_fecha'			=> mysql_real_escape_string($fecha_incidencia),
						'usuario_comentario'	=> mysql_real_escape_string($comment),
						'fecha_envio'			=> date('Y-m-d H:i:s')
					));
					
					?>
					<center>
						<h3><?php _e('Su reclamo ha sido enviado, le confirmaremos por e-mail si los datos se enviaron correctamente.'); ?></h3>
					</center>
				<?php else: ?>
					<form action="" method="post" id="form-reclamos" class="group">
						<div class="form-reclamos-left">
							<p>
								<input type="text" name="ct_nombre" value="" id="ct_nombre" class="required" tabindex="1" placeholder="<?php _e( 'Nombre(s)*' ); ?>">
								<em><?php _e( 'Este campo es obligatorio.' ); ?></em>
							</p>
							<p>
								<input type="text" name="ct_apellido_paterno" value="" id="ct_apellido_paterno" class="required" tabindex="2" placeholder="<?php _e( 'Apellido Paterno*' ); ?>">
								<em><?php _e( 'Este campo es obligatorio.' ); ?></em>
							</p>
							<p>
								<input type="text" name="ct_apellido_materno" value="" id="ct_apellido_materno" class="required" tabindex="3" placeholder="<?php _e( 'Apellido Materno*' ); ?>">
								<em><?php _e( 'Este campo es obligatorio.' ); ?></em>
							</p>
							<p><?php _e( 'Tipo de documento.' ); ?></p>	
							<p>
								<select name="ct_tipo_doc" id="ct_tipo_doc" tabindex="4">
									<option value="DNI"><?php _e( 'DNI' ); ?></option>
									<option value="RUC"><?php _e( 'RUC' ); ?></option>
									<option value="Pasaporte"><?php _e( 'Nro. Pasaporte' ); ?></option>
								</select>
								<em><?php _e( 'Ingrese una dirección de email válida.' ); ?></em>
							</p>
							<p>
								<input type="text" name="ct_nro_doc" value="" id="ct_nro_doc" class="required" tabindex="5" placeholder="<?php _e( 'Nro. de Documento*' ); ?>">
								<em><?php _e( 'Este campo es obligatorio.' ); ?></em>
							</p>
							<p>
								<input type="text" name="ct_direccion" value="" id="ct_direccion" class="required" tabindex="6" placeholder="<?php _e( 'Dirección*' ); ?>">
								<em><?php _e( 'Este campo es obligatorio.' ); ?></em>
							</p>
						</div>
						
						<div class="form-reclamos-right">
							<p>
								<input type="text" name="ct_departamento" value="" id="ct_departamento" class="required" tabindex="7" placeholder="<?php _e( 'Departamento*'); ?>">
								<em><?php _e( 'Este campo es obligatorio.' ); ?></em>
							</p>
							<p>
								<input type="text" name="ct_provincia" value="" id="ct_provincia" class="required" tabindex="8" placeholder="<?php _e( 'Provincia*' ); ?>">
								<em><?php _e( 'Este campo es obligatorio.' ); ?></em>
							</p>
							<p>
								<input type="text" name="ct_distrito" value="" id="ct_distrito" class="required" tabindex="9" placeholder="<?php _e( 'Distrito*' ); ?>">
								<em><?php _e( 'Este campo es obligatorio.' ); ?></em>
							</p>
							<p>
								<input type="text" name="ct_telefono" value="" id="ct_telefono" class="required" tabindex="10" placeholder="<?php _e( 'Teléfono*' ); ?>">
								<em><?php _e( 'Este campo es obligatorio.' ); ?></em>
							</p>
							<p>
								<input type="text" name="ct_fecha_incidencia" value="" id="ct_fecha_incidencia" class="required" tabindex="11" placeholder="<?php _e( 'Fecha de incidencia*' ); ?>">
								<em><?php _e( 'Este campo es obligatorio.' ); ?></em>
							</p>
		
							<p>
								<input type="text" name="ct_email" value="" id="ct_email" class="required email" tabindex="12" placeholder="<?php _e( 'Email*' ); ?>">
								<em><?php _e( 'Ingrese una dirección de email válida.' ); ?></em>
							</p>
						</div>
						
						<p>
							<textarea id="ct_comentario" rows="8" cols="45" name="ct_comentario" id="ct_comentario" class="required" tabindex="13" placeholder="<?php _e( 'Escriba aquí su reclamo' ); ?>"></textarea>
							<em><?php _e( 'Este campo es obligatorio.' ); ?></em>
						</p>
						<p><input type="submit" value="<?php _e('Enviar'); ?>" name="ct_submit" id="ct_submit" class="button b_submit" tabindex="14"></p>
					</form>
				<?php endif; ?>
			</div><!-- #contact-form -->
			<?php
	}

	static function register_script() {
		wp_register_script('reclamos-validate', plugins_url('js/jquery.validate.min.js', __FILE__), array('jquery'), '1.10', true);
		wp_register_script('reclamos-front-script', plugins_url('js/front.js', __FILE__), array('jquery'), '1.0', true);
		wp_register_style( 'reclamos-main-style', plugins_url('css/main.css', __FILE__) , false, '1.0', 'all' );
	}

	static function print_script() {
		if ( ! self::$add_script )
			return;

		wp_print_scripts( array( 'reclamos-validate', 'reclamos-front-script' ) );
		wp_print_styles('reclamos-main-style');
	}
}

pwreclamaciones_shortcode::init();

/********** Admin page **********/

add_action( 'admin_menu', 'pwreclamaciones_panel_admin_menu' );
add_action( 'admin_init', 'pwreclamaciones_admin_init' );


function pwreclamaciones_panel_admin_menu() {
	
	add_menu_page( __( 'Libro de Reclamaciones' ), __( 'Reclamos' ), 'activate_plugins', 'pw_reclamaciones', 'pwreclamaciones_panel_content');
	
	// Add menu link to the admin bar
	function pwpanel_add_admin_menu() {
		global $wp_admin_bar;
		$wp_admin_bar->add_menu( array(
			'parent'	=>	false,
			'id'		=>	'80',
			'title'		=>	__( 'Reclamaciones' ),
			'meta'		=>	false
		));
	}
	add_action( 'wp_before_admin_bar_render', 'pwpanel_add_admin_menu' );
	
}

function pwreclamaciones_panel_content() {
	?>
	<div class="wrap">
		<div id="icon-themes" class="icon32">
			<br>
		</div>
		<h2><?php _e('Libro de Reclamaciones'); ?></h2>
		<div id="pw_warp">
			<div class="panelcontent">
				<div id="message-append">
					<div id="top-message" class="updated saved">
						<p><?php printf( __('Copie y pegue el siguiente %1s en cualquier página donde quiera que aparezca el formulario de reclamaciones: %2s'), '<strong>shortcode</strong>', '<code>[formulario-reclamaciones]</code>' ); ?></p>
					</div>
				</div>
				<p>
			</div>
			
			<a href="http://www.paginasweb.pe" target="_blank">
				<img src="<?php echo plugins_url('img/pw-logo-admin.png', __FILE__); ?>" alt="PaginasWeb.pe" width="185" style="float: right;">
			</a>
			<h3 class="title"><?php _e('Reclamos guardados'); ?></h3>
			<p><?php _e('A continuación de mostrará una lista de reclamos, desde el más reciente a los más antiguos.'); ?></p>
			
			<div class="panelcontent">
				<table width="100%" class="lista-reclamos">
					<thead>
						<tr>
							<th><?php _e('Usuario'); ?></th>
							<th><?php _e('Domicilio'); ?></th>
							<th><?php _e('Contacto'); ?></th>
							<th><?php _e('Reclamo'); ?></th>
						</tr>
					</thead>
					<tbody>
						<?php
						global $wpdb;
						$table_name = $wpdb->prefix . 'pwreclamaciones';
						$results = $wpdb->get_results("Select * From " . $table_name . " Order By reclamo_id DESC");
						
						foreach ( $results as $reclamo ) :
						?>
						<tr>
							<td>
								<strong><?php _e('Nombre completo'); ?></strong><br>
								<?php echo $reclamo->usuario_nombre . ' ' . $reclamo->usuario_ap_paterno . ' ' . $reclamo->usuario_ap_materno; ?><br>
								<strong>Documento de Identidad</strong><br>
								<?php echo $reclamo->usuario_documento; ?>
							</td>
							<td>
								<strong><?php _e('Dirección'); ?></strong><br>
								<?php echo $reclamo->usuario_direccion; ?><br>
								<strong><?php _e('Departamento'); ?></strong><br>
								<?php echo $reclamo->usuario_departamento; ?><br>
								<strong><?php _e('Provincia'); ?></strong><br>
								<?php echo $reclamo->usuario_provincia; ?><br>
								<strong><?php _e('Distrito'); ?></strong><br>
								<?php echo $reclamo->usuario_distrito; ?><br>
							</td>
							<td>
								<strong><?php _e('Email'); ?></strong><br>
								<?php echo $reclamo->usuario_email; ?><br>
								<strong><?php _e('Teléfono'); ?></strong><br>
								<?php echo $reclamo->usuario_telefono; ?><br>
							</td>
							<td>
								<strong><?php _e('Fecha de incidencia'); ?></strong><br>
								<?php echo $reclamo->usuario_fecha; ?><br>
								<strong><?php _e('Fecha de envío'); ?></strong><br>
								<?php echo $reclamo->fecha_envio; ?><br><br>
								<strong><?php _e('Comentario'); ?></strong><br>
								<?php echo $reclamo->usuario_comentario ?>
							</td>
						</tr>
						<?php
						endforeach;
						?>
					</tbody>
				</table>
				
			</div><!-- .panelcontent -->
		</div><!-- #pw_warp -->
	</div>
	<?php
}

function pwreclamaciones_admin_init(){
	if( isset( $_GET['page'] ) && $_GET['page'] == 'pw_reclamaciones' ) {

		wp_enqueue_style('reclamos-admin-style', plugins_url('css/admin.css', __FILE__) , false, '1.0', 'all' );		
	}
}

//add_action('admin_menu', 'pwreclamaciones_notifications');

/*function pwreclamaciones_notifications() {
    global $menu;
    $newitem = get_number_of_new_post_by_type('post');
    //$menu[11][0] .= $newitem ? "<span class='update-plugins count-1'><span class='update-count'>$newitem </span></span>" : '';
    $menu[100][0] .= " <span class='update-plugins count-1'><span class='update-count'>5 </span></span>";
}

function get_number_of_new_post_by_type($type)
{
    global $wpdb;
    //return $wpdb->get_var( $wpdb->prepare( "SELECT COUNT(*) FROM {$wpdb->prefix}withdraw WHERE wd_status=0;" ) );
}*/


?>